	function Phase = PZ_2_PHASE_S(G, Z, P, W)
	%
	% 	Computes the phase response from the poles and zeros for 
	% 	an analog transfer function at the frequencies specified by W.
	%
	% 	Toolbox for ANALOG FILTERS USING MATLAB, Springer, 2009
	
	% 	Author: 		Lars Wanhammar, 2005-11-04
	% 	Modified by: 	LW 2011-01-23 
	% 	Copyright:		Divison of Electronics Systems
	% 					Dept. Electrical Engineering, Linkoping University, Sweden
	% 	Version: 		1
	% 	Known bugs:		None
	%	Report bugs to:	larsw@isy.liu.se
	%
	jOmega = j*W;
	if size(P) < size(Z)
		disp('Error, more zeros than poles')
		return;
	end
	if (G < 0) 
		Phase = -pi*ones(1,length(W));
	else
		Phase = zeros(1,length(W));
	end
	for n = 1:length(P)
		Phase = Phase - angle(jOmega-P(n)); 
	end
	for n = 1:length(Z)	
		Phase = Phase + angle(jOmega-Z(n));
	end
	for n = 1:length(W)
		if Phase(n) < -pi
			for m = n:length(W)
				Phase(m) = Phase(m)+2*pi;
			end
		end
		if Phase(n) > pi
			for m = n:length(W)
				Phase(m) = Phase(m)-2*pi;
			end
		end
	end
	
